@@ -63,7 +63,7 @@ use CPAN::Checksums ();
 use vars qw{$VERSION $CHECK_OWNER};
 
 BEGIN {
-	$VERSION = '0.11';
+	$VERSION = '1.12';
 
 	# Attempt to determine whether or not we are capable
 	# of finding the owner of a directory.
@@ -300,9 +300,14 @@ sub add {
 	my $to_dir  = File::Basename::dirname($to_file);
 
 	# Make the path for the file
-	eval { File::Path::mkpath($to_dir) };
-	if ( my $e = $@ ) {
-		Carp::croak("Failed to create $to_dir: $e");
+	SCOPE: {
+		local $@;
+		eval {
+			File::Path::mkpath($to_dir);
+		};
+		if ( my $e = $@ ) {
+			Carp::croak("Failed to create $to_dir: $e");
+		}
 	}
 
 	# Copy the file to the directory, and ensure writable
@@ -312,9 +317,14 @@ sub add {
 		or Carp::croak("Failed to correct permissions for $to_file");
 
 	# Update the checksums file, and ensure writable
-	eval { CPAN::Checksums::updatedir($to_dir); };
-	if ( my $e = $@ ) {
-		Carp::croak("Failed to update CHECKSUMS after insertion: $e");
+	SCOPE: {
+		local $@;
+		eval {
+			CPAN::Checksums::updatedir($to_dir);
+		};
+		if ( my $e = $@ ) {
+			Carp::croak("Failed to update CHECKSUMS after insertion: $e");
+		}
 	}
 	chmod( 0644, File::Spec->catfile( $to_dir, 'CHECKSUMS' ) )
 		or Carp::croak("Failed to correct permissions for CHECKSUMS");
@@ -353,9 +363,14 @@ sub remove {
 	# Update the checksums file
 	my $to_file = $self->file_path($name);
 	my $to_dir  = File::Basename::dirname($to_file);
-	eval { CPAN::Checksums::updatedir($to_dir); };
-	if ( my $e = $@ ) {
-		Carp::croak("Failed to update CHECKSUMS after removal: $e");
+	SCOPE: {
+		local $@;
+		eval {
+			CPAN::Checksums::updatedir($to_dir);
+		};
+		if ( my $e = $@ ) {
+			Carp::croak("Failed to update CHECKSUMS after removal: $e");
+		}
 	}
 
 	return 1;
@@ -503,7 +518,7 @@ L<CPAN::Mini::Inject>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2007 Adam Kennedy.
+Copyright 2006 - 2010 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
